==> goblin-2.6.3.tgz: include/goblin.2.6/goblin.h <==

/*
**  This file forms part of the GOBLIN C++ Class Library.
**
**  Written by Christian Fremuth-Paeger, July 2001.
**  
**  Copying, compiling, distribution and modification
**  of this source code is permitted only in accordance
**  with the GOBLIN general licence information.
*/             


#if !defined(_GOBLIN_H_)

#define _GOBLIN_H_


#include <config.h>
#include <globals.h>
#include <context.h>
#include <timers.h>

#include <absobj.h>
#include <absmix.h>
#include <absgra.h>
#include <absbig.h>
#include <absdig.h>
#include <absbal.h>
#include <absfam.h>
#include <iterator.h>

#include <import.h>
#include <export.h>

#include <genstruc.h>
#include <spsstruc.h>
#include <dnsstruc.h>

#include <spsmix.h>
#include <spsgra.h>
#include <spsbig.h>
#include <spsdig.h>
#include <spsbal.h>
#include <dnsgra.h>
#include <dnsbig.h>
#include <dnsdig.h>

#include <gra2bal.h>
#include <bal2bal.h>
#include <fnw2fnw.h>
#include <big2fnw.h>
#include <surgra.h>
#include <auxnet.h>
#include <shrnet.h>

#include <queue.h>
#include <statq.h>
#include <dynq.h>
#include <statstaq.h>
#include <dynstaq.h>
#include <setfam.h>
#include <shrfam.h>
#include <basheap.h>
#include <binheap.h>
#include <fibheap.h>

#include <matrix.h>
#include <hashtbl.h>
#include <dictionary.h>

#include <ilpWrap.h>
#include <lpSolve.h>

#include <bbscheme.h>
#include <bbstable.h>
#include <bbatsp.h>
#include <bbstsp.h>
#include <bbcolour.h>

#include <display.h>
#include <exp2tk.h>
#include <exp2xfig.h>

#include <treeView.h>

#include <abstractSubgraph.h>
#include <subgraph.h>
#include <complement.h>
#include <segment.h>
    

#endif

==> goblin-2.6.4.tgz: include/goblin.2.6/goblin.h <==

/*
**  This file forms part of the GOBLIN C++ Class Library.
**
**  Written by Christian Fremuth-Paeger, July 2001.
**  
**  Copying, compiling, distribution and modification
**  of this source code is permitted only in accordance
**  with the GOBLIN general licence information.
*/             


#if !defined(_GOBLIN_H_)

#define _GOBLIN_H_


#include <config.h>
#include <globals.h>
#include <context.h>
#include <timers.h>

#include <absobj.h>
#include <absmix.h>
#include <absgra.h>
#include <absbig.h>
#include <absdig.h>
#include <absbal.h>
#include <absfam.h>
#include <iterator.h>

#include <import.h>
#include <export.h>

#include <genstruc.h>
#include <spsstruc.h>
#include <dnsstruc.h>

#include <spsmix.h>
#include <spsgra.h>
#include <spsbig.h>
#include <spsdig.h>
#include <spsbal.h>
#include <dnsgra.h>
#include <dnsbig.h>
#include <dnsdig.h>

#include <gra2bal.h>
#include <bal2bal.h>
#include <fnw2fnw.h>
#include <big2fnw.h>
#include <surgra.h>
#include <auxnet.h>
#include <shrnet.h>

#include <queue.h>
#include <statq.h>
#include <dynq.h>
#include <statstaq.h>
#include <dynstaq.h>
#include <setfam.h>
#include <shrfam.h>
#include <basheap.h>
#include <binheap.h>
#include <fibheap.h>

#include <matrix.h>
#include <hashtbl.h>
#include <dictionary.h>

#include <ilpWrapper.h>
#include <lpSolve.h>

#include <bbscheme.h>
#include <bbstable.h>
#include <bbatsp.h>
#include <bbstsp.h>
#include <bbcolour.h>

#include <display.h>
#include <exp2tk.h>
#include <exp2xfig.h>

#include <treeView.h>

#include <abstractSubgraph.h>
#include <subgraph.h>
#include <complement.h>
#include <segment.h>
    

#endif
